-- 
-- Container Arm Script by Zippo
-- 

ivecoarm = {};

function ivecoarm.prerequisitesPresent(specializations)
     Vehicle.registerJointType("frontloader");
     return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function ivecoarm:load(xmlFile)

    	local translationA2Node = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.translationA2#index"));
    if translationA2Node ~= nil then
        self.translationA2 = {};
        self.translationA2.node = translationA2Node;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.translationA2#minTrans"));
        self.translationA2.minTrans = {};
        self.translationA2.minTrans[1] = Utils.getNoNil(x, 0);
        self.translationA2.minTrans[2] = Utils.getNoNil(y, 0);
        self.translationA2.minTrans[3] = Utils.getNoNil(z, 0);

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.translationA2#maxTrans"));
        self.translationA2.maxTrans = {};
        self.translationA2.maxTrans[1] = Utils.getNoNil(x, 0);
        self.translationA2.maxTrans[2] = Utils.getNoNil(y, 0);
        self.translationA2.maxTrans[3] = Utils.getNoNil(z, 0);

        self.translationA2.transTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.translationA2#transTime"), 2)*1000;
        self.translationA2.touchTransLimit = Utils.getNoNil(getXMLString(xmlFile, "vehicle.translationA2#touchTransLimit"), 10);
    end;

	local translationA5Node = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.translationA5#index"));
    if translationA5Node ~= nil then
        self.translationA5 = {};
        self.translationA5.node = translationA5Node;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.translationA5#minTrans"));
        self.translationA5.minTrans = {};
        self.translationA5.minTrans[1] = Utils.getNoNil(x, 0);
        self.translationA5.minTrans[2] = Utils.getNoNil(y, 0);
        self.translationA5.minTrans[3] = Utils.getNoNil(z, 0);

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.translationA5#maxTrans"));
        self.translationA5.maxTrans = {};
        self.translationA5.maxTrans[1] = Utils.getNoNil(x, 0);
        self.translationA5.maxTrans[2] = Utils.getNoNil(y, 0);
        self.translationA5.maxTrans[3] = Utils.getNoNil(z, 0);

        self.translationA5.transTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.translationA5#transTime"), 2)*1000;
        self.translationA5.touchTransLimit = Utils.getNoNil(getXMLString(xmlFile, "vehicle.translationA5#touchTransLimit"), 10);
    end;

hydraA5SoundFile = Utils.getFilename("hydraA1.wav", self.baseDirectory);
    self.hydraA5SoundId = createSample("HYDA5_hydraA5");
    loadSample(self.hydraA5SoundId, hydraA5SoundFile, false);
    self.hydraA5Playing = false;
hydraA2SoundFile = Utils.getFilename("hydraA2.wav", self.baseDirectory);
    self.hydraA2SoundId = createSample("HYDA2_hydraA2");
    loadSample(self.hydraA2SoundId, hydraA2SoundFile, false);
    self.hydraA2Playing = false;	

end;	
      
function ivecoarm:delete()
end;

function ivecoarm:mouseEvent(posX, posY, isDown, isUp, button)
end;
	  
function ivecoarm:keyEvent(unicode, sym, modifier, isDown)
	if self.isMotorStarted then
	
	if sym == Input.KEY_KP_7 then
		self.translationA2Max = isDown;
	end;
	if sym == Input.KEY_KP_4 then
		self.translationA2Min = isDown;
	end;
	if sym == Input.KEY_KP_5 then
		self.translationA5Max = isDown;
	end;
	if sym == Input.KEY_KP_8 then
		self.translationA5Min = isDown;
	end;
      end;
end;

function ivecoarm:update(dt)
				
	
	local doTranslate = self.translationA2Max or self.translationA2Min 
	if self.translationA2 ~= nil and doTranslate then 
		local x, y, z = getTranslation(self.translationA2.node); 
		local trans = {x,y,z}; 
		local newTrans = Utils.getMovedLimitedValues(trans, self.translationA2.maxTrans, self.translationA2.minTrans, 3, self.translationA2.transTime, dt, not self.translationA2Max); 
		setTranslation(self.translationA2.node, unpack(newTrans));
	if not self.hydraA2Playing then
            playSample(self.hydraA2SoundId, 0, 1, 0);
            self.hydraA2Playing = true;
        end;
    else
        if self.hydraA2Playing then
            stopSample(self.hydraA2SoundId);
            self.hydraA2Playing = false;
        end; 
	end; 
	local doTranslate = self.translationA5Max or self.translationA5Min 
	if self.translationA5 ~= nil and doTranslate then 
		local x, y, z = getTranslation(self.translationA5.node); 
		local trans = {x,y,z}; 
		local newTrans = Utils.getMovedLimitedValues(trans, self.translationA5.maxTrans, self.translationA5.minTrans, 3, self.translationA5.transTime, dt, not self.translationA5Max); 
		setTranslation(self.translationA5.node, unpack(newTrans));
	if not self.hydraA5Playing then
            playSample(self.hydraA5SoundId, 0, 1, 0);
            self.hydraA5Playing = true;
        end;
    else
        if self.hydraA5Playing then
            stopSample(self.hydraA5SoundId);
            self.hydraA5Playing = false;
        end; 
     end;		
end;

function ivecoarm:draw()

     if self.isMotorStarted then
        g_currentMission:addExtraPrintText("Keypad 7 / 4 : Arm Zurck/Vor");
	g_currentMission:addExtraPrintText("Keypad 8 / 5 : Lift Hoch/Runter");
	g_currentMission:addExtraPrintText("Arbeitslicht - L");
	end;

end;

function ivecoarm:validateAttacherJoint(implement, jointDesc, dt)
    return true;
end;

